/*  linux/include/linux/timeofday.h
 *
 *  This file contains the interface to the time of day subsystem
 */
#ifndef _LINUX_TIMEOFDAY_H
#define _LINUX_TIMEOFDAY_H
#include <linux/calc64.h>
#include <linux/types.h>
#include <linux/ktime.h>
#include <linux/time.h>
#include <linux/timex.h>

#ifdef CONFIG_GENERIC_TIME

/* Kernel internal interfaces */
extern ktime_t get_monotonic_clock(void);
extern ktime_t get_realtime_clock(void);
extern ktime_t get_realtime_offset(void);

/* Timepsec based interfaces for user space functionality */
extern void get_realtime_clock_ts(struct timespec *ts);
extern void get_monotonic_clock_ts(struct timespec *ts);

/* legacy timeofday interfaces*/
#define getnstimeofday(ts) get_realtime_clock_ts(ts)
#define getnstimestamp(ts) get_monotonic_clock_ts(ts)
extern void getnstimeofday(struct timespec *ts);
extern void do_gettimeofday(struct timeval *tv);
extern int do_settimeofday(struct timespec *ts);

/* Internal functions */
extern int timeofday_is_continuous(void);
extern void timeofday_init(void);

#ifndef CONFIG_IS_TICK_BASED
#define arch_getoffset() (0)
#else
extern unsigned long arch_getoffset(void);
#endif

#else /* CONFIG_GENERIC_TIME */
#define timeofday_init()
extern void getnstimeofday(struct timespec *ts);
extern void getnstimestamp(struct timespec *ts);
#endif /* CONFIG_GENERIC_TIME */
#endif /* _LINUX_TIMEOFDAY_H */
